Changes
=======


0.0.6-alpha
-----
- Alpha release
- Add CareTeam endpoints
- Add ActivityDefinition DELETE methods
- Fix async methods for SOPH token request


0.0.5-alpha
-----
- Alpha release
- Minor fixes discovered during tests
- Add POST / PUT prefer headers
- Fix name iterators


0.0.4-alpha
-----
- Alpha release
- Minor fixes discovered during tests, code improvements


0.0.3-alpha
-----
- Alpha release
- JWKS utils for basic operations, load keys from config


0.0.2-alpha
-----
- Alpha release
- Connect to Koppeltaal OAuth endpoint and handle JWKS token
- Read - Patient, Practitioner and Endpoint resources.
- Create, Read, Update, Delete - Task, ActivityDefinition resources.

0.0.1
-----
Setup basic koppeltaal package
